/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse;

import org.eclipse.gef.ContextMenuProvider;
import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.ui.IWorkbenchActionConstants;

import be.ac.vub.cocompose.eclipse.actions.CreateImplementationGeneratorAction;
import be.ac.vub.cocompose.eclipse.actions.CreateImplementationPatternAction;
import be.ac.vub.cocompose.eclipse.actions.CreateImplementationRolePartAction;
import be.ac.vub.cocompose.eclipse.actions.CreateSimplePropertyAction;
import be.ac.vub.cocompose.eclipse.actions.CreateSolutionPatternAction;

/**
 * CoCompose context menu.
 * @author Dennis Wagelaar
 * @version 0.2.0, 08/01/2004
 * @since 0.2.0
 */
public class CoComposeContextMenuProvider extends ContextMenuProvider
{

  /**
   * @uml property=actionRegistry associationEnd={multiplicity={(1 1)}}
   */
  private ActionRegistry actionRegistry;


  /**
   * Creates a CoCompose context menu provider.
   * @param viewer
   * @param registry
   */
  public CoComposeContextMenuProvider(EditPartViewer viewer, ActionRegistry registry)
  {
    super(viewer);
    setActionRegistry(registry);
  }

  /**
   * @see org.eclipse.gef.ContextMenuProvider#buildContextMenu(org.eclipse.jface.action.IMenuManager)
   */
  public void buildContextMenu(IMenuManager manager)
  {
    // New Actions
    MenuManager newmenu = new MenuManager("&New");

    IAction action = getActionRegistry().getAction(CreateSolutionPatternAction.ID);
    if (action.isEnabled())
      newmenu.add(action);

    action = getActionRegistry().getAction(CreateImplementationPatternAction.ID);
    if (action.isEnabled())
      newmenu.add(action);

    action = getActionRegistry().getAction(CreateImplementationGeneratorAction.ID);
    if (action.isEnabled())
      newmenu.add(action);

    action = getActionRegistry().getAction(CreateImplementationRolePartAction.ID);
    if (action.isEnabled())
      newmenu.add(action);

    if (!newmenu.isEmpty())
      newmenu.add(new Separator());

    action = getActionRegistry().getAction(CreateSimplePropertyAction.ID);
    if (action.isEnabled())
      newmenu.add(action);

    if (!newmenu.isEmpty())
      manager.add(newmenu);

    // GEF crap...
    GEFActionConstants.addStandardActionGroups(manager);

    action = getActionRegistry().getAction(GEFActionConstants.UNDO);
    manager.appendToGroup(GEFActionConstants.GROUP_UNDO, action);

    action = getActionRegistry().getAction(GEFActionConstants.REDO);
    manager.appendToGroup(GEFActionConstants.GROUP_UNDO, action);

    // TODO paste
//    action = getActionRegistry().getAction(IWorkbenchActionConstants.PASTE);
//    if (action.isEnabled())
//      manager.appendToGroup(GEFActionConstants.GROUP_EDIT, action);

    action = getActionRegistry().getAction(IWorkbenchActionConstants.DELETE);
    if (action.isEnabled())
      manager.appendToGroup(GEFActionConstants.GROUP_EDIT, action);

    action = getActionRegistry().getAction(GEFActionConstants.DIRECT_EDIT);
    if (action.isEnabled())
      manager.appendToGroup(GEFActionConstants.GROUP_EDIT, action);

    // Alignment Actions
    MenuManager submenu = new MenuManager("&Align");

    action = getActionRegistry().getAction(GEFActionConstants.ALIGN_LEFT);
    if (action.isEnabled())
      submenu.add(action);

    action = getActionRegistry().getAction(GEFActionConstants.ALIGN_CENTER);
    if (action.isEnabled())
      submenu.add(action);

    action = getActionRegistry().getAction(GEFActionConstants.ALIGN_RIGHT);
    if (action.isEnabled())
      submenu.add(action);

    action = getActionRegistry().getAction(GEFActionConstants.ALIGN_TOP);
    if (action.isEnabled())
      submenu.add(action);

    action = getActionRegistry().getAction(GEFActionConstants.ALIGN_MIDDLE);
    if (action.isEnabled())
      submenu.add(action);

    action = getActionRegistry().getAction(GEFActionConstants.ALIGN_BOTTOM);
    if (action.isEnabled())
      submenu.add(action);

    if (!submenu.isEmpty())
      manager.appendToGroup(GEFActionConstants.GROUP_REST, submenu);
  }

  /**
   * Gets the action registry.
   * @return the action registry.
   * @uml property=actionRegistry
   */
  private ActionRegistry getActionRegistry()
  {
    return actionRegistry;
  }

  /**
   * Sets the action registry. 
   * @param registry the action registry.
   * @uml property=actionRegistry
   */
  private void setActionRegistry(ActionRegistry actionRegistry)
  {
    this.actionRegistry = actionRegistry;
  }

}
