/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.actions;

import org.eclipse.gef.commands.Command;
import org.eclipse.ui.IEditorPart;

import be.ac.vub.cocompose.eclipse.CoComposeImages;
import be.ac.vub.cocompose.eclipse.commands.CreateCommand;
import be.ac.vub.cocompose.lang.ModelFactory;
import be.ac.vub.cocompose.lang.core.ImplementationGenerator;

/**
 * Creates an ImplementationGenerator for the selected Concept.
 * @author Dennis Wagelaar
 * @version 0.2.0, 08/01/2004
 * @since 0.2.0
 */
public class CreateImplementationRolePartAction extends CreateAction
{
  public static final String ID = "CreateImplementationRolePart";

  /**
   * Creates a CreateImplementationGeneratorAction.
   * @param editor the CoCompose editor.
   */
  public CreateImplementationRolePartAction(IEditorPart editor, ModelFactory factory)
  {
    super(editor, factory, ImplementationGenerator.class);
    setText("Role part");
    setId(ID);
    setToolTipText("Creates a role part within the selected implementation generator");
    setImageDescriptor(CoComposeImages.IMPL_RP_OBJ);
  }

  /**
   * Creates the command to be executed.
   * @return the command.
   */
  protected Command getCommand()
  {
    CreateCommand cmd = (CreateCommand) super.getCommand();
    cmd.setElement(factory.createImplementationRolePart());
    return cmd;
  }
}
