/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.commands;

import java.awt.Point;

import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.commands.Command;

import be.ac.vub.cocompose.lang.core.RelationElement;

/**
 * Command for setting size and position constraints.
 * @author Dennis Wagelaar
 * @version 0.2.0, 09/01/2004
 * @since 0.2.0
 */
public class SetConstraintCommand extends Command
{
  private Point newPos;

  /**
   * @uml property=newSize associationEnd={multiplicity={(0 1)}}
   */
  private Dimension newSize;

  private Point oldPos;

  /**
   * @uml property=oldSize associationEnd={multiplicity={(1 1)}}
   */
  private Dimension oldSize = new Dimension(-1, -1);

  /**
   * @uml property=element associationEnd={multiplicity={(0 1)}}
   */
  private RelationElement element;


  /**
   * @see org.eclipse.gef.commands.Command#execute()
   */
  public void execute() 
  {
    oldPos  = element.getPosition();
    element.setPosition(newPos);
  }

  /**
   * @see org.eclipse.gef.commands.Command#getLabel()
   */
  public String getLabel()
  {
    if (oldSize.equals(newSize))
      return "Location";
    return "Resize";
  }

  /**
   * @see org.eclipse.gef.commands.Command#redo()
   */
  public void redo() 
  {
    element.setPosition(newPos);
  }

  /**
   * @see org.eclipse.gef.commands.Command#undo()
   */
  public void undo() 
  {
    element.setPosition(oldPos);
  }

  /**
   * Sets the position and size.
   * @param position - the positional data.
   */
  public void setPosition(Rectangle position)
  {
    setPosition(new Point(position.x, position.y));
    setSize(position.getSize());
  }

  /**
   * Sets the position.
   * @param position - the position.
   */
  public void setPosition(Point position) {
    newPos = position;
  }

  /**
   * Sets the size.
   * @param size - the size.
   */
  public void setSize(Dimension size) {
    newSize = size;
  }

  /**
   * Sets the element to position and/or size.
   * @param element - the element.
   * @uml property=element
   */
  public void setElement(RelationElement element)
  {
    this.element = element;
  }

}
