/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.editparts;

import java.beans.PropertyChangeEvent;

import org.eclipse.draw2d.Graphics;
import org.eclipse.draw2d.IFigure;

import be.ac.vub.cocompose.eclipse.figures.ConceptFigure;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.Role;

/**
 * Eclipse editpart controller for EclipseConcept objects.
 * @author Dennis Wagelaar
 * @version 0.2.1, 13/01/2004
 * @since 0.2.0
 */
public class RoleEditPart extends RefinedElementEditPart
{
  /**
   * Handles changes in properties of this. It is
   * activated through the PropertyChangeListener.
   * It updates children, source and target connections,
   * and the visuals of this based on the property
   * changed.
   * @param evt  Event which details the property change.
   * @see java.beans.PropertyChangeListener#propertyChange(java.beans.PropertyChangeEvent)
   */
  public void propertyChange(PropertyChangeEvent evt)
  {
    String id = evt.getPropertyName();
    if (id.equals(Properties.ID_MULTIPLICITY))
      refreshVisuals();
    else super.propertyChange(evt);
  }

  /**
   * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#createFigure()
   */
  protected IFigure createFigure()
  {
    ConceptFigure fig = (ConceptFigure) super.createFigure();
    fig.setLinestyle(Graphics.LINE_DASH);
    return fig;
  }

  /**
   * @see org.eclipse.gef.editparts.AbstractEditPart#refreshVisuals()
   */
  protected void refreshVisuals() 
  {
    getConceptFigure().setLabel(getRole().getName() + ' ' + getRole().getMultiplicity());
    super.refreshVisuals();
  }

  /**
   * Gets the model associated with this.
   * @return the model associated with this.
   */
  protected Role getRole()
  {
    return (Role) getModel();
  }
}
