/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.figures;

import org.eclipse.draw2d.Figure;
import org.eclipse.draw2d.FreeformLayer;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.StackLayout;
import org.eclipse.draw2d.geometry.Insets;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.handles.HandleBounds;
import org.eclipse.swt.graphics.Image;

/**
 * Eclipse figure for displaying concepts.
 * @author Dennis Wagelaar
 * @version 0.2.4, 22/01/2004
 * @since 0.2.0
 */
public class ConceptFigure extends Figure implements HandleBounds
{
  /**
   * @uml property=pane associationEnd={multiplicity={(1 1)}}
   */
  private FreeformLayer pane;

  /**
   * @uml property=border associationEnd={multiplicity={(1 1)}}
   */
  private ConceptBorder border;

  /**
   * Creates a ConceptFigure. 
   */
  public ConceptFigure()
  {
    super();
    pane = new FreeformLayer();
    pane.setLayoutManager(new ConceptLayout());
    border = new ConceptBorder();
    setBorder(border);
    setLayoutManager(new StackLayout());
    setOpaque(true);
    add(pane);
  }

  /**
   * Checks if this figure contains other figures.
   * @return true if this figure contains other figures.
   */
  public boolean hasChildren()
  {
    return pane.getChildren().size() > 0;
  }

  /**
   * @see org.eclipse.gef.handles.HandleBounds#getHandleBounds()
   */
  public Rectangle getHandleBounds()
  {
    return getBounds().getCropped(new Insets(0,0,0,0));
  }

  /**
   * Gets the pane for embedded contents.
   * @return the pane for embedded contents.
   */
  public IFigure getContentPane()
  {
    return pane;
  }
  
  /**
   * Gets the label string.
   * @return the label string.
   */
  public String getLabel()
  {
    return border.getLabel();
  }
  
  /**
   * Sets the label string.
   * @param label - the label string.
   */
  public void setLabel(String label)
  {
    this.border.setLabel(label);
  }

  /**
   * Returns true if the border is bold.
   * @return true if the border is bold.
   */
  public boolean isBold()
  {
    return border.isBold();
  }
  
  /**
   * Returns true if the border is bold.
   * @param bold true if the border is bold.
   */
  public void setBold(boolean bold)
  {
    border.setBold(bold);
  }

  /**
   * @see org.eclipse.draw2d.IFigure#invalidate()
   */  
  public void invalidate()
  {
    border.setUnderline(pane.getChildren().size() > 0);
    border.invalidate();
    super.invalidate();
  }

  /**
   * Gets the line style
   * @return the line style
   * @see org.eclipse.draw2d.Graphics
   */  
  public int getLinestyle()
  {
    return border.getLinestyle();
  }

  /**
   * Gets the line style
   * @param linestyle the line style
   * @see org.eclipse.draw2d.Graphics
   */  
  public void setLinestyle(int linestyle)
  {
    border.setLinestyle(linestyle);
    invalidate();
  }

  /**
   * Sets the icon image.
   * @param icon the icon.
   */
  public void setIcon(Image icon)
  {
    border.setIcon(icon);
    invalidate();
  }

  /**
   * Gets the icon image.
   * @return the icon.
   */
  public Image getIcon()
  {
    return border.getIcon();
  }

  /**
   * @see org.eclipse.draw2d.Figure#useLocalCoordinates()
   */
  protected boolean useLocalCoordinates()
  {
    return true;
  }
}
