/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.model;

import java.io.File;
import java.net.URL;

import org.eclipse.core.internal.runtime.Assert;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.ICellEditorValidator;

import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.lang.core.RefinedElement;

/**
 * Validates CoCompose RefinedElement icon URIs.
 * @author Dennis Wagelaar
 * @version 0.2.4, 22/01/2004
 * @since 0.2.1
 */
public class IconValidator implements ICellEditorValidator
{

  /**
   * The subject to validate the icon URI for.
   * @uml property=subject associationEnd={multiplicity={(1 1)}}
   */
  private RefinedElement subject = null;

  /**
   * Creates an IconValidator.
   */
  public IconValidator(RefinedElement subject)
  {
    this.subject = subject;
  }

  /**
   * @see org.eclipse.jface.viewers.ICellEditorValidator#isValid(java.lang.Object)
   */
  public String isValid(Object value)
  {
    if ((subject != null) && (value instanceof String))
    {
      String uri = (String) value;
      if (uri.length() == 0)
        return null;
      try
      { // if no protocol specified, assume this is a file path
        if (uri.indexOf(':') == -1)
        { // if no protocol specified, assume this is a file path
          Model model = subject.getModel();
          Assert.isNotNull(model);
          String parent = new File(model.getUri()).getParentFile().getAbsolutePath();
          String file = new File(parent, uri).getAbsolutePath();
          // TODO debug println
          System.out.println("icon URI = " + file);
//          String file = new File(uri).getAbsolutePath();
          if (ImageDescriptor.createFromFile(null, file).createImage(false) == null)
            return "No image found at given URL";
        }
        else
        { // else parse URI
          URL url = new URL(uri);
          if (ImageDescriptor.createFromURL(url).createImage(false) == null)
            return "No image found at given URL";
        }
      }
      catch (Exception e)
      {
        return e.getMessage();
      }
    }
    return null;
  }
}
