/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.model.core;

import java.util.List;
import java.util.Vector;

import org.eclipse.core.internal.runtime.Assert;
import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.PropertyDescriptor;

import be.ac.vub.cocompose.eclipse.model.EclipseElement;
import be.ac.vub.cocompose.eclipse.model.IPropertyDescriptorCreator;
import be.ac.vub.cocompose.eclipse.model.datatypes.ModelElementPropertySource;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.Concept;
import be.ac.vub.cocompose.lang.impl.core.DefaultModel;


/**
 * The Model language element for Eclipse.
 * @author Dennis Wagelaar 
 * @version 0.2.4, 22/01/2004
 * @since 0.2.0
 */
public class EclipseModel extends DefaultModel implements IPropertyDescriptorCreator 
{
  public static final String ID_ROUTER = "router";

  /**
   * @uml property=element associationEnd={multiplicity={(1 1)}}
   */
  private EclipseElement element = new EclipseElement(this);
  private ModelElementPropertySource defConceptPS = null; 

  /**
   * Creates the property descriptors.
   * @return the property descriptors.
   */
  public List createDescriptors()
  {
    List descs = new Vector();
    // name
    descs.add(new PropertyDescriptor(Properties.ID_NAME, "name"));
    // uri
    descs.add(new PropertyDescriptor(Properties.ID_URI, "URI"));
    return descs;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
   */
  public Object getPropertyValue(Object id)
  {
    if (Properties.ID_NAME.equals(id))
    {
      if (getName() == null)
        return new String();
      else
        return new String(getName());
    }
    if (Properties.ID_URI.equals(id))
    {
      if (getUri() == null)
        return new String();
      else
        return new String(getUri());
    }
    if (Properties.ID_DEFAULT_CONCEPT.equals(id))
    {
      if (defConceptPS == null)
        return new Integer(0);
      else
        return defConceptPS.getPropertyValue(id);
    }
    return element.getPropertyValue(id);
  }

  /**
   * Sets the value of a given property with the value supplied.
   * Also fires a property change if necessary.
   * @param id - Name of the parameter to be changed.
   * @param value - Value to be set to the given parameter.
   * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
   */
  public void setPropertyValue(Object id, Object value)
  {
    if (Properties.ID_DEFAULT_CONCEPT.equals(id))
    {
      Assert.isNotNull(defConceptPS);
      defConceptPS.setPropertyValue(id, value);
      if (getDefaultConcept() != null)
        getDefaultConcept().setDefaultConceptOf(null);
      Concept newConcept = (Concept) defConceptPS.getModelElement();
      setDefaultConcept(newConcept);
      if (newConcept != null)
        newConcept.setDefaultConceptOf(this);
    }
    else element.setPropertyValue(id, value);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
   */
  public void resetPropertyValue(Object id)
  {
    if (Properties.ID_DEFAULT_CONCEPT.equals(id))
    {
      setDefaultConcept(null);
    }
    else element.resetPropertyValue(id);
  }

  /**
   * Re-creates ModelElementPropertySource descriptors each time.
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
   */
  public IPropertyDescriptor[] getPropertyDescriptors()
  {
    // defaultConcept
    defConceptPS = new ModelElementPropertySource(getDefaultConcept(), this, 
      Concept.class, Properties.ID_DEFAULT_CONCEPT, "default concept");
    IPropertyDescriptor[] dcd = defConceptPS.getPropertyDescriptors();
    IPropertyDescriptor[] d = element.getPropertyDescriptors();
    IPropertyDescriptor[] nd = new IPropertyDescriptor[d.length + dcd.length];
    for (int i = 0; i < d.length; i++)
    {
      nd[i] = d[i];
    }
    for (int i = 0; i < dcd.length; i++)
    {
      nd[i + d.length] = dcd[i];
    }
    return nd;
  }

  /////////////////////////////////////////////////////////////////////////////
  // Delegate to EclipseElement
  /////////////////////////////////////////////////////////////////////////////

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
   */
  public boolean isPropertySet(Object id)
  {
    return element.isPropertySet(id);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
   */
  public Object getEditableValue()
  {
    return element.getEditableValue();
  }
}
