/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.model.core;

import java.util.List;
import java.util.Vector;

import org.eclipse.draw2d.Bendpoint;
import org.eclipse.ui.views.properties.IPropertyDescriptor;

import be.ac.vub.cocompose.eclipse.model.EclipseElement;
import be.ac.vub.cocompose.eclipse.model.IPropertyDescriptorCreator;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.impl.core.DefaultRelationship;

/**
 * Eclipse representation for CoCompose language elements that can participate in a relationship.
 * @author Dennis Wagelaar
 * @version 0.2.0, 09/04/2004
 * @since 0.2.0
 */
public class EclipseRelationship extends DefaultRelationship implements IPropertyDescriptorCreator
{

  /**
   * @uml property=element associationEnd={multiplicity={(1 1)}}
   */
  private EclipseElement element = new EclipseElement(this);

  /**
   * @uml property=bendpoints associationEnd={multiplicity={(0 -1)} elementType=org.eclipse.draw2d.Bendpoint}
   * 
   */
  private List bendpoints = new Vector();


  /**
   * Inserts a bendpoint at the given index.
   * @param index - the index for insertion.
   * @param point - the bendpoint to insert.
   */
  public void insertBendpoint(int index, Bendpoint point)
  {
    bendpoints.add(index, point);
    firePropertyChange(Properties.ID_BENDPOINT, null, null);
  }

  /**
   * Removes the bendpoint at the given index.
   * @param index - the index of the bendpoint.
   */
  public void removeBendpoint(int index)
  {
    bendpoints.remove(index);
    firePropertyChange(Properties.ID_BENDPOINT, null, null);
  }

  /**
   * Sets the bendpoint at the given index.
   * @param index - the index for insertion.
   * @param point - the bendpoint to set.
   */
  public void setBendpoint(int index, Bendpoint point)
  {
    bendpoints.set(index, point);
    firePropertyChange(Properties.ID_BENDPOINT, null, null);
  }

  /**
   * Sets the bendpoints.
   * @param points - the bendpoints to set.
   * @uml property=bendpoints
   */
  public void setBendpoints(List points)
  {
    bendpoints = points;
    firePropertyChange(Properties.ID_BENDPOINT, null, null);
  }

  /**
   * Gets the bendpoints.
   * @return the bendpoints.
   * @uml property=bendpoints
   */
  public List getBendpoints()
  {
    return bendpoints;
  }

  
  /**
   * Creates the property descriptors.
   * @return the property descriptors.
   */
  public List createDescriptors()
  {
    List descs = new Vector();
    return descs;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
   */
  public Object getPropertyValue(Object id)
  {
    return element.getPropertyValue(id);
  }

  /**
   * Sets the value of a given property with the value supplied.
   * Also fires a property change if necessary.
   * @param id - Name of the parameter to be changed.
   * @param value - Value to be set to the given parameter.
   * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
   */
  public void setPropertyValue(Object id, Object value)
  {
    element.setPropertyValue(id, value);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
   */
  public void resetPropertyValue(Object id)
  {
    element.resetPropertyValue(id);
  }

  /////////////////////////////////////////////////////////////////////////////
  // Delegate to EclipseElement
  /////////////////////////////////////////////////////////////////////////////

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
   */
  public boolean isPropertySet(Object id)
  {
    return element.isPropertySet(id);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
   */
  public Object getEditableValue()
  {
    return element.getEditableValue();
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
   */
  public IPropertyDescriptor[] getPropertyDescriptors()
  {
    return element.getPropertyDescriptors();
  }
}
