/*
 * Created on 23-jun-2003
 */
package be.ac.vub.cocompose.eclipse.model.datatypes;

import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.IPropertySource;
import org.eclipse.ui.views.properties.TextPropertyDescriptor;

/**
 * Eclipse dimension property source.
 * @author Dennis Wagelaar
 * @version 0.2.0
 * @since 0.2.0
 */
public class DimensionPropertySource implements IPropertySource
{
  public static final String ID_WIDTH  = "width";
  public static final String ID_HEIGHT = "height";

  private static IPropertyDescriptor[] descriptors;

  /**
   * @uml property=dimension associationEnd={multiplicity={(1 1)}}
   */
  private Dimension dimension = null;

  static{
    descriptors = new IPropertyDescriptor[] {
      new TextPropertyDescriptor(ID_WIDTH, "width"),
      new TextPropertyDescriptor(ID_HEIGHT, "height")
    };
  }

  /**
   * Creates a DimensionPropertySource.
   * @param dimension - the subject dimension.
   */
  public DimensionPropertySource(Dimension dimension)
  {
    super();
    this.dimension = new Dimension(dimension);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
   */
  public Object getEditableValue()
  {
    return this;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
   */
  public IPropertyDescriptor[] getPropertyDescriptors()
  {
    return descriptors;
  }

  /**
   * Gets the value of the given property.
   * @param id - the property id.
   * @return the property value or null.
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
   */
  public Object getPropertyValue(Object id)
  {
    if (ID_HEIGHT.equals(id))
    {
      return new String(new Integer(dimension.height).toString());
    }
    if (ID_WIDTH.equals(id))
    {
      return new String(new Integer(dimension.width).toString());
    }
    return null;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
   */
  public boolean isPropertySet(Object id)
  {
    return true;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
   */
  public void resetPropertyValue(Object id)
  {
  }

  /**
   * Sets the value of the given property.
   * @param id - the property id.
   * @param value - the new value for the property.
   * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
   */
  public void setPropertyValue(Object id, Object value)
  {
    if (ID_WIDTH.equals(id))
    {
      Integer width = new Integer((String) value);
      dimension.width = width.intValue();
    }
    if (ID_HEIGHT.equals(id)) 
    {
      Integer height = new Integer((String) value);
      dimension.height = height.intValue();
    }
  }

  /**
   * Gets the value of this property source.
   * @return the property value.
   */
  public Dimension getValue()
  {
    return new Dimension(dimension);
  }
}
