/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.model.datatypes;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.IPropertySource;
import org.eclipse.ui.views.properties.TextPropertyDescriptor;

/**
 * Eclipse point property source.
 * @author Dennis Wagelaar
 * @version 0.2.0, 12/12/2003
 * @since 0.2.0
 */
public class PointPropertySource implements IPropertySource
{
  public static final String ID_X = "x";
  public static final String ID_Y = "y";

  private static IPropertyDescriptor[] descriptors;

  /**
   * @uml property=point associationEnd={multiplicity={(1 1)}}
   */
  private Point point = null;

  static{
    descriptors = new IPropertyDescriptor[] {
      new TextPropertyDescriptor(ID_X, "x"),
      new TextPropertyDescriptor(ID_Y, "y")
    };
  }

  /**
   * Creates a PointPropertySource.
   * @param point - the subject point.
   */
  public PointPropertySource(Point point)
  {
    super();
    this.point = new Point(point);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
   */
  public Object getEditableValue()
  {
    return this;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
   */
  public IPropertyDescriptor[] getPropertyDescriptors()
  {
    return descriptors;
  }

  /**
   * Gets the value of the given property.
   * @param id - the property id.
   * @return the property value or null.
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
   */
  public Object getPropertyValue(Object id)
  {
    if (ID_X.equals(id))
    {
      return new String(new Integer(point.x).toString());
    }
    if (ID_Y.equals(id))
    {
      return new String(new Integer(point.y).toString());
    }
    return null;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
   */
  public boolean isPropertySet(Object id)
  {
    return true;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
   */
  public void resetPropertyValue(Object id)
  {
  }

  /**
   * Sets the value of the given property.
   * @param id - the property id.
   * @param value - the new value for the property.
   * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
   */
  public void setPropertyValue(Object id, Object value)
  {
    if (ID_X.equals(id))
    {
      try
      {
        Integer x = new Integer((String) value);
        point.x = x.intValue();
      }
      catch (NumberFormatException e)
      { // don't set
      }
    }
    if (ID_Y.equals(id)) 
    {
      try
      {
        Integer y = new Integer((String) value);
        point.y = y.intValue();
      }
      catch (NumberFormatException e)
      { // don't set
      }
    }
  }

  /**
   * Gets the value of this property source.
   * @return the property value.
   */
  public Point getValue()
  {
    return new Point(point);
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    if (point != null)
      return point.toString();
    else
      return super.toString();
  }
}
