/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.io.xmi;

import java.util.Hashtable;

import org.xml.sax.Attributes;

import be.ac.vub.cocompose.lang.DefaultSuperModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.core.Concept;
import be.ac.vub.cocompose.lang.core.Model;

/**
 * Reads the XMI linked attributes of CoCompose model elements
 * @author Dennis Wagelaar
 * @version 0.2.4, 22/01/2004
 * @since 0.2.3
 */
public class XMIElementLinkAttributesReader extends DefaultSuperModelVisitor
{
  /**
   * @uml property=atts associationEnd={multiplicity={(0 1)}}
   */
  private Attributes atts = null;
  /**
   * @uml property=elementMap associationEnd={multiplicity={(0 1)} qualifier=(ref:java.lang.String
   * value:be.ac.vub.cocompose.lang.core.RefinedElement)}
   */
  private Hashtable elementMap = new Hashtable();
  
  /**
   * Creates an XMIModelLinkReader
   * @param elementMap the map of id -&gt; element
   */
  public XMIElementLinkAttributesReader(Hashtable elementMap)
    throws ModelElementException
  {
    if (elementMap == null)
      throw new ModelElementException("ElementMap may not be null");
    this.elementMap = elementMap;
  }

  /**
   * Sets the parsed XML attributes
   * @param atts the parsed XML attributes
   */
  public void setAttributes(Attributes atts)
  {
    this.atts = atts;
  }

  /**
   * Visits a Model.
   * @param model - the element to visit.
   * @exception ModelElementException
   */
  public void visitModel(Model model) throws ModelElementException
  {
    super.visitModel(model);
    String defConceptId = atts.getValue(XMI.CoCompose.qName("defaultConcept"));
    if (defConceptId != null)
    {
      Object defConcept = elementMap.get(defConceptId);
      if (defConcept instanceof Concept)
      {
        model.setDefaultConcept((Concept) defConcept);
        ((Concept) defConcept).setDefaultConceptOf(model);
      }
    }
  }
}
