/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.core;

/**
 * Interface for relationships between CoCompose language elements.
 * @version 0.2.0, 02/12/2003
 * @since 0.2.0
 * @author Dennis Wagelaar
 */
public interface Relationship extends ModelElement
{

  /**
   * @clientRole relationship
   * @clientCardinality 0..* {ordered}
   * @supplierRole participant
   * @supplierCardinality 2
   * @uml property=sourceParticipant associationEnd={multiplicity={(0 1)}}
   */
  public RelationElement getSourceParticipant();

  /**
   * Sets the first participant in this relationship.
   * @param sourceParticipant - the source participant.
   * @uml property=sourceParticipant
   */
  public void setSourceParticipant(RelationElement sourceParticipant);

  /**
   * Gets the second participant in this relationship.
   * @return the target participant.
   * @uml property=targetParticipant associationEnd={multiplicity={(0 1)}}
   */
  public RelationElement getTargetParticipant();

  /**
   * Sets the second participant in this relationship.
   * @param targetParticipant - the target participant.
   * @uml property=targetParticipant
   */
  public void setTargetParticipant(RelationElement targetParticipant);

}
