/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.core;

import java.util.List;
import be.ac.vub.cocompose.lang.datatypes.Multiplicity;

/**
 * The Solution Role language element interface.
 * @author Dennis Wagelaar 
 * @version 0.2.0, 03/12/2003
 * @since 0.1.0
 */
public interface Role extends RefinedElement
{

  /**
   * @supplierRole part
   * @supplierCardinality 0..* 
   * @clientRole partOf
   * @clientCardinality 0..
   * @uml property=parts
   */
  public List getParts();


  /**
   * Adds a concept to the role part.
   * @param concept - the concept to add. 
   */
  public void addPart(Concept concept);

  /**
   * Adds a concept to the role part.
   * @param index the index at which to add the element.
   * @param concept - the concept to add. 
   */
  public void addPart(int index, Concept concept);

  /**
   * Removes a concept from the role part.
   * @param concept - the concept to remove. 
   */
  public void removePart(Concept concept);

  /**
   * Returns the multiplicity constraint for this solution role.
   * @return the multiplicity constraint.
   * @uml property=multiplicity associationEnd={multiplicity={(0 1)}}
   */
  public Multiplicity getMultiplicity();

  /**
   * Sets the multiplicity constraint for this solution role.
   * @param multiplicity the multiplicity constraint.
   * @uml property=multiplicity
   */
  public void setMultiplicity(Multiplicity multiplicity);

}
