package be.ac.vub.cocompose.lang.impl.constraints;

import java.util.List;
import java.util.Vector;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.constraints.CompositeConstraint;
import be.ac.vub.cocompose.lang.constraints.Constraint;
import be.ac.vub.cocompose.lang.core.ModelElement;
import be.ac.vub.cocompose.lang.ModelVisitor;

/**
 * Composite constraint.
 * @author Dennis Wagelaar 
 * @version 0.2.0
 * @since 0.2.0
 */
abstract public class DefaultCompositeConstraint extends DefaultConstraint implements CompositeConstraint
{

  /**
   * @link aggregation
   * @clientRole ownerConstraint
   * @supplierRole ownedConstraint
   * @supplierCardinality 2..*
   * @clientCardinality 0..1
   * @associates <{be.ac.vub.cocompose.lang.impl.constraints.DefaultConstraint}>
   * @undirected
   * @uml property=ownedConstraints associationEnd={multiplicity={(0 -1)} elementType=be.ac.vub.cocompose.lang.constraints.Constraint}
   * 
   */
  private Vector ownedConstraints = new Vector();

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.*/
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitCompositeConstraint(this);
  }

  /**
   * Invokes superclass accept().
   * @param modelVisitor The visitor to accept.
   * @see #accept(ModelVisitor)*/
  public void acceptSuper(ModelVisitor modelVisitor) throws ModelElementException
  {
    super.accept(modelVisitor);
  }

  /**
   * Returns the child constraints.
   * @return a copy of the List of child constraints.
   */
  public List getOwnedConstraints()
  {
    return (List) ownedConstraints.clone();
  }

  /**
   * Adds an element to this namespace.
   * @param index - the index at which to add the element.
   * @param modelElement - the element to add.
   * @exception ModelElementException - if the name of the element is already used within this namespace. 
   */
  public void addOwnedElement(int index, ModelElement modelElement) throws ModelElementException
  {
    super.addOwnedElement(index, modelElement);
    if (modelElement instanceof Constraint)
      addOwnedConstraint(translateIndex(index, ownedConstraints), (Constraint) modelElement);
  }

  /**
   * Removes a element from this namespace.
   * @param modelElement - the element to remove. 
   */
  public void removeOwnedElement(ModelElement modelElement)
  {
    if (modelElement instanceof Constraint)
      removeOwnedConstraint((Constraint) modelElement);
    super.removeOwnedElement(modelElement);
  }

  /**
   * Adds a child constraint.
   * @param index - the index at which to add the element.
   * @param constraint - the constraint to add. 
   * @exception ModelElementException - if the name of the element is already used within this namespace.
   */
  private void addOwnedConstraint(int index, Constraint constraint) throws ModelElementException
  {
    if (index > -1)
      ownedConstraints.add(index, constraint);
    else
      ownedConstraints.add(constraint);
    constraint.setOwnerConstraint(this);
  }

  /**
   * Removes a child constraint.
   * @param constraint - the constraint to remove. 
   */
  private void removeOwnedConstraint(Constraint constraint)
  {
    ownedConstraints.remove(constraint);
  }
}
