package be.ac.vub.cocompose.lang.impl.constraints;

import java.util.Iterator;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.constraints.OrConstraint;
import be.ac.vub.cocompose.lang.constraints.Constraint;
import be.ac.vub.cocompose.lang.ModelVisitor;

/**
 * Boolean "or" composite constraint interface.
 * @author Dennis Wagelaar
 * @version 0.2.0
 * @since 0.2.0
 */
public class DefaultOrConstraint extends DefaultCompositeConstraint implements OrConstraint
{
  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.*/
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitOrConstraint(this);
  }

  /**
   * Invokes superclass accept().
   * @param modelVisitor The visitor to accept.
   * @see #accept(ModelVisitor)*/
  public void acceptSuper(ModelVisitor modelVisitor) throws ModelElementException
  {
    super.accept(modelVisitor);
  }

  /**
   * Checks whether the constraint holds.
   * @exception ModelElementException - if the constraint doesn't hold.
   */
  protected void concreteCheck() throws ModelElementException
  {
    ModelElementException lastException = null;
    Iterator ownedConstr = getOwnedConstraints().iterator();
    while (ownedConstr.hasNext())
    {
      try
      {
        ((Constraint) ownedConstr.next()).check();
        return;
      }
      catch (ModelElementException e)
      {
      }
    }
    if (lastException != null)
      throw lastException;
  }
}
