/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.impl.core;

import java.awt.Color;
import java.util.List;
import java.util.Vector;

import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.Concept;
import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.lang.core.RefinedElement;
import be.ac.vub.cocompose.lang.core.Role;

/**
 * The Concept language element default implementation.
 * @author Dennis Wagelaar 
 * @version 0.2.5, 03/03/2004
 * @since 0.2.0
 */
public class DefaultConcept extends DefaultRefinedElement implements Concept 
{

  /**
   * @uml property=partOf associationEnd={multiplicity={(0 -1)} elementType=be.ac.vub.cocompose.lang.core.Role}
   * 
   */
  private Vector partOf = new Vector();
  private Model defaultConceptOf = null;

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.
   */
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitConcept(this);
  }

  /**
   * Gets the roles of which this concept is a part.
   * @return the roles.
   */
  public List getPartOf()
  {
    return (List) partOf;
  }

  /**
   * Adds a role of which this concept is a part.
   * @param partOf the role.
   */
  public void addPartOf(Role partOf)
  {
    addPartOf(-1, partOf);
  }

  /**
   * Adds a role of which this concept is a part.
   * @param index the index at which to add the element.
   * @param partOf the role.
   */
  public void addPartOf(int index, Role partOf)
  {
    if (this.partOf.contains(partOf))
      return;
    if (index > -1)
      this.partOf.add(index, partOf);
    else
      this.partOf.add(partOf);
    fireStructureChange(Properties.ID_PART_OF, partOf);
    fireBackgroundColorUpdate();
  }

  /**
   * Removes a role of which this concept is a part.
   * @param partOf the role.
   */
  public void removePartOf(Role partOf)
  {
    this.partOf.remove(partOf);
    fireStructureChange(Properties.ID_PART_OF, partOf);
    fireBackgroundColorUpdate();
  }
  
  /**
   * Gets the background color. Returns the background color of the
   * partOf role, if only one partOf role exists. Returns the color
   * of the parent namespace if it is a RefinedElement.
   * @return the background color.
   * @see be.ac.vub.cocompose.lang.core.RefinedElement
   */
  public Color getBackgroundColor()
  {
    if (getPartOf().size() == 1)
    {
      return ((Role) getPartOf().get(0)).getBackgroundColor();
    }
    else if (getNamespace() instanceof RefinedElement)
    {
      return ((RefinedElement) getNamespace()).getBackgroundColor();
    }
    else
    {
      return super.getBackgroundColor();
    }
  }

  /**
   * Gets the model of which this concept is the default concept, if any.
   * @return the model of which this concept is the default concept, if any.
   */
  public Model getDefaultConceptOf()
  {
    return defaultConceptOf;
  }
  
  /**
   * Sets the model of which this concept is the default concept, if any.
   * @param model the model of which this concept is the default concept, if any.
   */
  public void setDefaultConceptOf(Model model)
  {
    defaultConceptOf = model;
    firePropertyChange(Properties.ID_DEFAULT_CONCEPT_OF, null, model);
  }
}
