/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.impl.core;

import java.util.List;
import java.util.Vector;

import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.ImplementationGenerator;
import be.ac.vub.cocompose.lang.core.ImplementationRolePart;
import be.ac.vub.cocompose.lang.core.ModelElement;

/**
 * The Implementation Generator language element.
 * @author Dennis Wagelaar 
 * @version 0.2.0, 02/12/2003
 * @since 0.2.0
 */
public class DefaultImplementationGenerator extends DefaultRefinement implements ImplementationGenerator
{

  /**
   * @clientRole implementationGenerator
   * @clientCardinality 1
   * @supplierRole rolePart
   * @supplierCardinality 0..*
   * @link aggregation
   * @undirected
   * @associates <{DefaultImplementationRolePart}>
   * @uml property=roleParts associationEnd={multiplicity={(0 -1)} elementType=be.ac.vub.cocompose.lang.core.ImplementationRolePart}
   * 
   */
  private Vector roleParts = new Vector();

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.*/
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitImplementationGenerator(this);
  }

  /**
   * Adds an element to this namespace.
   * @param index - the index at which to add the element.
   * @param modelElement - the element to add.
   * @exception ModelElementException - if the name of the element is already used within this namespace. 
   */
  public void addOwnedElement(int index, ModelElement modelElement) throws ModelElementException
  {
    super.addOwnedElement(index, modelElement);
    if (modelElement instanceof ImplementationRolePart)
      addRolePart(translateIndex(index, roleParts), (ImplementationRolePart) modelElement);
  }

  /**
   * Removes a element from this namespace.
   * @param modelElement - the element to remove. 
   */
  public void removeOwnedElement(ModelElement modelElement)
  {
    if (modelElement instanceof ImplementationRolePart)
      removeRolePart((ImplementationRolePart) modelElement);
    super.removeOwnedElement(modelElement);
  }

  /**
   * Adds a role part to this implementation generator.
   * @param index - the index at which to add the element.
   * @param rolePart - the role part to add.
   * @exception ModelElementException - if the name of the element is already used within this namespace. 
   */
  private void addRolePart(int index, ImplementationRolePart rolePart) throws ModelElementException
  {
    if (index > -1)
      roleParts.add(index, rolePart);
    else
      roleParts.add(rolePart);
    rolePart.setImplementationGenerator(this);
    fireStructureChange(Properties.ID_ROLE_PARTS, rolePart);
  }

  /**
   * Removes a role part from this implementation generator.
   * @param rolePart - the role part to remove. 
   */
  private void removeRolePart(ImplementationRolePart rolePart)
  {
    roleParts.remove(rolePart);
    fireStructureChange(Properties.ID_ROLE_PARTS, rolePart);
  }

  /**
   * Gets the role parts for this implementation generator.
   * @return a copy of the List of role parts.
   */
  public List getRoleParts()
  {
    return (List) roleParts;
  }
}
