/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.impl.core;

import be.ac.vub.cocompose.lang.core.ImplementationGenerator;
import be.ac.vub.cocompose.lang.core.ImplementationRolePart;
import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.Properties;

/**
 * The Implementation Generator role part language element.
 * @author Dennis Wagelaar 
 * @version 0.2.0, 02/12/2003
 * @since 0.2.0
 */
public class DefaultImplementationRolePart extends DefaultNamespace implements ImplementationRolePart 
{

  /**
   * @uml property=implementationGenerator associationEnd={multiplicity={(0 1)}}
   */
  private ImplementationGenerator implementationGenerator = null;

  /**
   * Gets the implementation generator for this role part.
   * @return the implementation generator.
   * @uml property=implementationGenerator
   */
  public ImplementationGenerator getImplementationGenerator()
  {
    return implementationGenerator;
  }

  /**
   * Sets the implementation generator for this role part.
   * @param implementationGenerator - the implementation generator.
   * @uml property=implementationGenerator
   */
  public void setImplementationGenerator(ImplementationGenerator implementationGenerator)
  {
    this.implementationGenerator = implementationGenerator;
    firePropertyChange(
      Properties.ID_IMPLEMENTATION_GEN,
      null,
      implementationGenerator);
  }

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.*/
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitImplementationRolePart(this);
  }
}
