/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.impl.core;

import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.Refinement;
import be.ac.vub.cocompose.lang.core.RefinedElement;

/**
 * Represents language element refinements.
 * @author Dennis Wagelaar 
 * @version 0.2.0, 09/01/2004
 * @since 0.2.0
 */
abstract public class DefaultRefinement extends DefaultNamespace implements Refinement
{

  /**
   * @uml property=refinedElement associationEnd={multiplicity={(0 1)}}
   */
  private RefinedElement refinedElement = null;

  /**
   * Gets the owner refined element.
   * @return the owner refined element.
   * @uml property=refinedElement
   */
  public RefinedElement getRefinedElement()
  {
    return refinedElement;
  }

  /**
   * Sets the owner refined element.
   * @param refinedElement - the owner refined element.
   * @uml property=refinedElement
   */
  public void setRefinedElement(RefinedElement refinedElement)
  {
    this.refinedElement = refinedElement;
    firePropertyChange(Properties.ID_REFINED_ELEMENT, null, refinedElement);
  }

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.
   */
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitRefinement(this);
  }
}
