/**
 * Title:        CoCompose
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: University of Twente, Vrije Universiteit Brussel
 * Description:  CoCompose Design Language Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.impl.core;

import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.Relationship;
import be.ac.vub.cocompose.lang.core.RelationElement;

/**
 * Interface for relationships between CoCompose language elements.
 * @version 0.2.0, 07/01/2003
 * @since 0.2.0
 * @author Dennis Wagelaar 
 */
public class DefaultRelationship extends DefaultModelElement implements Relationship
{

  /**
   * @uml property=sourceParticipant associationEnd={multiplicity={(0 1)}}
   */
  private RelationElement sourceParticipant = null;

  /**
   * @uml property=targetParticipant associationEnd={multiplicity={(0 1)}}
   */
  private RelationElement targetParticipant = null;


  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.
   */
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitRelationship(this);
  }

  /**
   * Gets the first participant in this relationship.
   * @return the source participant.
   * @uml property=sourceParticipant
   */
  public RelationElement getSourceParticipant()
  {
    return sourceParticipant;
  }

  /**
   * Sets the first participant in this relationship.
   * @param sourceParticipant - the source participant.
   * @uml property=sourceParticipant
   */
  public void setSourceParticipant(RelationElement sourceParticipant)
  {
    this.sourceParticipant = sourceParticipant;
    firePropertyChange(Properties.ID_SOURCE, null, sourceParticipant);
  }

  /**
   * Gets the second participant in this relationship.
   * @return the target participant.
   * @uml property=targetParticipant
   */
  public RelationElement getTargetParticipant()
  {
    return targetParticipant;
  }

  /**
   * Sets the second participant in this relationship.
   * @param targetParticipant - the target participant.
   * @uml property=targetParticipant
   */
  public void setTargetParticipant(RelationElement targetParticipant)
  {
    this.targetParticipant = targetParticipant;
    firePropertyChange(Properties.ID_TARGET, null, targetParticipant);
  }

  
  /**
   * @see be.ac.vub.cocompose.lang.core.ModelElement#getName()
   */
  public String getName()
  {
    if ((getSourceParticipant() != null) && (getTargetParticipant() != null))
      return "Relationship(" + getSourceParticipant() + ", " +
        getTargetParticipant() + ")";
    else
      return super.getName();
  }
}
