/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.impl.core;

import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.SolutionPattern;

/**
 * The Solution Pattern language element.
 * @author Dennis Wagelaar 
 * @version 0.2.3, 20/01/2004
 * @since 0.2.0
 */
public class DefaultSolutionPattern extends DefaultRefinement implements SolutionPattern
{
  private String modelUri = null;

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.
   */
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitSolutionPattern(this);
  }

  /**
   * Gets the solution model URI.
   * @return the solution model URI.
   */
  public String getModelUri()
  {
    return modelUri;
  }

  /**
   * Sets the solution model URI.
   * @param modelUri the solution model URI.
   */
  public void setModelUri(String modelUri)
  {
    this.modelUri = modelUri;
    firePropertyChange(Properties.ID_MODEL_URI, null, modelUri);
  }
}
