/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.lang.impl.properties;

import be.ac.vub.cocompose.lang.properties.ModelProperty;
import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.core.Model;

/**
 * Delegates to a model as property.
 * @author Dennis Wagelaar 
 * @version 0.2.0, 08/01/2004
 * @since 0.2.0
 */
public class DefaultModelProperty extends DefaultProperty implements ModelProperty
{

  /**
   * @supplierRole model
   * @supplierCardinality 1
   * @associates be.ac.vub.cocompose.lang.impl.core.DefaultModel
   * @uml property=model associationEnd={multiplicity={(0 1)}}
   */
  private Model model = null;

  /**
   * Gets the property container model.
   * @return the model.
   * @uml property=model
   */
  public Model getModel()
  {
    return model;
  }

  /**
   * Sets the property container model.
   * @param model - the model.
   * @uml property=model
   */
  public void setModel(Model model)
  {
    this.model = model;
  }

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.*/
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitModelProperty(this);
  }

  /**
   * Invokes superclass accept().
   * @param modelVisitor The visitor to accept.
   * @see #accept(ModelVisitor)*/
  public void acceptSuper(ModelVisitor modelVisitor) throws ModelElementException
  {
    super.accept(modelVisitor);
  }
}
